@@ -1,6 +1,7 @@
 /* GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -23,6 +24,7 @@
 
 #include <assert.h>
 #include <ctype.h>
+#include <error.h>
 #include <getopt.h>
 #include <locale.h>
 #include <math.h>
@@ -39,7 +41,6 @@
 #include "closeout.h"
 #include "hash.h"
 #include "hash-pjw.h"
-#include "error.h"
 #include "lib/intprops.h"
 #include "quote.h"
 #include "ignore-value.h"
@@ -56,6 +57,7 @@
 #include "op-defs.h"
 #include "op-parser.h"
 #include "utils.h"
+#include "randutils.h"
 #include "field-ops.h"
 #include "crosstab.h"
 
@@ -114,13 +116,14 @@ enum
   OUTPUT_DELIMITER_OPTION,
   CUSTOM_FORMAT_OPTION,
   SORT_PROGRAM_OPTION,
+  VNLOG_OPTION,
   UNDOC_PRINT_INF_OPTION,
   UNDOC_PRINT_NAN_OPTION,
   UNDOC_PRINT_PROGNAME_OPTION,
   UNDOC_RMDUP_TEST
 };
 
-static char const short_options[] = "sfF:izg:t:HWR:Cc:";
+static char const short_options[] = "sS:fF:izg:t:HWR:Cc:hV";
 
 static struct option const long_options[] =
 {
@@ -133,12 +136,14 @@ static struct option const long_options[] =
   {"header-in", no_argument, NULL, INPUT_HEADER_OPTION},
   {"header-out", no_argument, NULL, OUTPUT_HEADER_OPTION},
   {"headers", no_argument, NULL, 'H'},
+  {"vnlog", no_argument, NULL, VNLOG_OPTION},
   {"full", no_argument, NULL, 'f'},
   {"filler", required_argument, NULL, 'F'},
   {"format", required_argument, NULL, CUSTOM_FORMAT_OPTION},
   {"output-delimiter", required_argument, NULL, OUTPUT_DELIMITER_OPTION},
   {"collapse-delimiter", required_argument, NULL,'c'},
   {"sort", no_argument, NULL, 's'},
+  {"seed", no_argument, NULL, 'S'},
   {"no-strict", no_argument, NULL, NO_STRICT_OPTION},
   {"narm", no_argument, NULL, REMOVE_NA_VALUES_OPTION},
   {"round", required_argument, NULL, 'R'},
@@ -153,7 +158,7 @@ static struct option const long_options[] =
   {NULL, 0, NULL, 0},
 };
 
-void
+static void
 group_columns_find_named_columns ()
 {
   for (size_t i = 0; i < dm->num_grps; ++i)
@@ -172,7 +177,7 @@ group_columns_find_named_columns ()
     }
 }
 
-void
+static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
@@ -220,7 +225,7 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
   mean, geomean, harmmean, trimmean, median, q1, q3, iqr, perc,\n\
   mode, antimode, pstdev, sstdev, pvar, svar, ms, rms, mad, madraw,\n\
   pskew, sskew, pkurt, skurt, dpo, jarque,\n\
-  scov, pcov, spearson, ppearson\n\
+  scov, pcov, spearson, ppearson, dotprod\n\
 \n", stdout);
       fputs ("\n", stdout);
 
@@ -251,6 +256,10 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
 "), stdout);
       fputs (_("\
   -H, --headers             same as '--header-in --header-out'\n\
+"), stdout);
+      fputs (_("\
+  --vnlog                   Reads and writes data in the vnlog format.\n\
+                              Implies -C -H -W\n\
 "), stdout);
       fputs (_("\
   -i, --ignore-case         ignore upper/lower case when comparing text;\n\
@@ -259,6 +268,9 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
       fputs (_("\
   -s, --sort                sort the input before grouping; this removes the\n\
                               need to manually pipe the input through 'sort'\n\
+"), stdout);
+      fputs (_("\
+  -S, --seed                set a seed for operations that use randomization\n\
 "), stdout);
       fputs (_("\
   -c, --collapse-delimiter=X  use X to separate elements in collapse and\n\
@@ -371,7 +383,7 @@ safe_line_record_get_fieldz (const struct line_record_t *lr, const size_t n,
 /* returns TRUE if the lines are different, false if identical.
  * comparison is based on the specified keys */
 /* copied from coreutils's src/uniq.c (in the key-spec branch) */
-static bool
+static bool _GL_ATTRIBUTE_PURE
 different (const struct line_record_t* l1, const struct line_record_t* l2)
 {
   for (size_t i = 0; i < dm->num_grps; ++i)
@@ -464,6 +476,9 @@ print_input_line (const struct line_record_t* lb)
 static void
 print_column_headers ()
 {
+  if ( vnlog )
+    printf ("# ");
+
   if (print_full_line)
     {
       /* Print the headers of all the input fields */
@@ -525,7 +540,7 @@ print_column_headers ()
   print_line_separator ();
 }
 
-void
+static void
 field_op_find_named_columns ()
 {
   for (size_t i=0; i<dm->num_ops; ++i)
@@ -551,7 +566,8 @@ process_input_header (FILE *stream)
   struct line_record_t lr;
 
   line_record_init (&lr);
-  if (line_record_fread (&lr, stream, eolchar, skip_comments))
+
+  if (line_record_fread (&lr, stream, eolchar, skip_comments, vnlog))
     {
       build_input_line_headers (&lr, true);
       line_number++;
@@ -563,7 +579,7 @@ process_input_header (FILE *stream)
   line_record_free (&lr);
 }
 
-void
+static void
 summarize_field_ops ()
 {
   for (size_t i=0;i<dm->num_ops;++i)
@@ -584,7 +600,7 @@ summarize_field_ops ()
   print_line_separator ();
 }
 
-void
+static void
 reset_field_ops ()
 {
   for (size_t i=0;i<dm->num_ops;++i)
@@ -662,12 +678,11 @@ is deprecated and will be disabled in a future release.\n"), stderr);
     print_column_headers ();
 
 
-  while (true)
+  while (line_record_fread (thisline, input_stream, eolchar,
+                            skip_comments, false))
     {
       bool new_group = false;
 
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
-        break;
       line_number++;
 
       /* If there's no input header line, and the user requested an output
@@ -742,7 +757,8 @@ transpose_file ()
       num_lines++;
       line_record_init (thisline);
 
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
+      if (!line_record_fread (thisline, input_stream, eolchar,
+                              skip_comments, false))
         break;
       line_number++;
 
@@ -797,10 +813,9 @@ reverse_fields_in_file ()
   thisline = &lr;
   line_record_init (thisline);
 
-  while (true)
+  while (line_record_fread (thisline, input_stream, eolchar, skip_comments,
+                            vnlog && line_number==0))
     {
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
-        break;
       line_number++;
 
       const size_t num_fields = line_record_num_fields (thisline);
@@ -818,6 +833,31 @@ reverse_fields_in_file ()
       /* Special handling for header line */
       if (line_number == 1)
         {
+          if (vnlog)
+            {
+              /* If using named-columns, find the column numbers after reading
+                 the header line. */
+              build_input_line_headers (&lr, true);
+              group_columns_find_named_columns ();
+
+              fprintf (stdout, "# ");
+              const size_t num_fields = line_record_num_fields (thisline);
+              for (size_t i = num_fields ; i >= 1 ; --i) {
+                if (i<num_fields)
+                  print_field_separator ();
+
+                const char *str;
+                size_t len;
+                if (line_record_get_field (thisline, i, &str, &len))
+                {
+                  ignore_value (fwrite (str, len, sizeof (char), stdout));
+                }
+              }
+              print_line_separator ();
+
+              continue;
+            }
+
           /* If there is an header line (first line), and the user did not
              request printing the header, skip it */
           if (input_header && !output_header)
@@ -866,10 +906,9 @@ noop_file ()
 
   thisline = &lr;
   line_record_init (thisline);
-  while (true)
+  while (line_record_fread (thisline, input_stream, eolchar,
+                            skip_comments, false))
     {
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
-        break;
       line_number++;
 
       if (print_full_line)
@@ -903,10 +942,9 @@ tabular_check_file ()
   line_record_init (thisline);
   line_record_init (prevline);
 
-  while (true)
+  while (line_record_fread (thisline, input_stream, eolchar,
+                            skip_comments, false))
     {
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
-        break;
       line_number++;
 
       const size_t num_fields = line_record_num_fields (thisline);
@@ -1012,7 +1050,8 @@ remove_dups_in_file ()
 
   if (input_header)
     {
-      if (line_record_fread (thisline, input_stream, eolchar, skip_comments))
+      if (line_record_fread (thisline, input_stream, eolchar,
+                             skip_comments, vnlog))
         {
           line_number++;
 
@@ -1026,6 +1065,8 @@ remove_dups_in_file ()
 
           if (output_header)
             {
+              if (vnlog)
+                fprintf (stdout, "# ");
               const size_t num_fields = line_record_num_fields (thisline);
               for (size_t i = 1 ; i <= num_fields ; ++i) {
                 if (i>1)
@@ -1049,10 +1090,9 @@ remove_dups_in_file ()
   /* TODO: handle (output_header && !input_header) by generating dummy headers
            after the first line is read, and the number of fields is known. */
 
-  while (true)
+  while (line_record_fread (thisline, input_stream, eolchar,
+                            skip_comments, false))
     {
-      if (!line_record_fread (thisline, input_stream, eolchar, skip_comments))
-        break;
       line_number++;
 
       if (!line_record_get_field (thisline, key_col, &str, &len))
@@ -1210,6 +1250,8 @@ int main (int argc, char* argv[])
   int optc;
   enum processing_mode premode = MODE_INVALID;
   const char* premode_group_spec = NULL;
+  bool force_seed = false;
+  unsigned long int seed = 0;
 
   DECL_LONG_DOUBLE_ROUNDING
   BEGIN_LONG_DOUBLE_ROUNDING ();
@@ -1228,7 +1270,6 @@ int main (int argc, char* argv[])
   textdomain (PACKAGE);
 
   init_blank_table ();
-  init_random ();
 
   atexit (close_stdout);
 
@@ -1258,6 +1299,15 @@ int main (int argc, char* argv[])
           case_sensitive = false;
           break;
 
+        case VNLOG_OPTION:
+          skip_comments        = true;
+          input_header         = output_header = true;
+          missing_field_filler = "-";
+          in_tab               = TAB_WHITESPACE;
+          out_tab              = ' ';
+          vnlog                = true;
+          break;
+
         case 'z':
           eolchar = 0;
           break;
@@ -1282,6 +1332,17 @@ int main (int argc, char* argv[])
           pipe_through_sort = true;
           break;
 
+        case 'S':
+          force_seed = true;
+          char *endptr;
+          errno = 0;
+          long proposed_seed = strtol (optarg, &endptr, 10);
+          if (errno || *endptr != '\0' || proposed_seed < 0)
+            die (EXIT_FAILURE, 0,
+                 _("invalid seed"));
+          seed = proposed_seed;
+          break;
+
         case NO_STRICT_OPTION:
           strict = false;
           break;
@@ -1355,6 +1416,8 @@ int main (int argc, char* argv[])
       usage (EXIT_FAILURE);
     }
 
+  init_random (force_seed, seed);
+
   /* If --output-delimiter=X was used, override any previous output delimiter */
   if (explicit_output_delimiter != -1)
     out_tab = explicit_output_delimiter ;
@@ -1371,6 +1434,34 @@ int main (int argc, char* argv[])
     die (EXIT_FAILURE, 0,
            _("-H or --header-in must be used with named columns"));
 
+  if (vnlog)
+    {
+      if (!skip_comments)
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always skips comments"));
+      if (!input_header)
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always reads field labels"));
+      if (!output_header)
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always reads field labels"));
+      if (!STREQ (missing_field_filler, "-"))
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always uses '-' for empty fields"));
+      if (in_tab != TAB_WHITESPACE)
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing is whitespace-delimited"));
+      if (out_tab != ' ')
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always uses ' ' to separate output fields"));
+      if (explicit_output_delimiter != -1)
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always uses the default output delimiter"));
+      if (eolchar != '\n')
+        die (EXIT_FAILURE, 0,
+             _("vnlog processing always uses '\\n' to terminate output lines"));
+    }
+
   open_input ();
   switch (dm->mode)                              /* LCOV_EXCL_BR_LINE */
     {
