@@ -1,5 +1,6 @@
 /* decorate -- auxiliary program for sort preprocessing
    Copyright (C) 2020-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -39,7 +40,7 @@
 #define PROGRAM_NAME "decorate"
 
 #define AUTHORS \
-  proper_name ("Assaf Gordon, Shawn Wagner and Erik Auerswald")
+  proper_name ("Assaf Gordon, Timothy Rice, Shawn Wagner and Erik Auerswald")
 
 static const char *sort_cmd = SORT_PATH;
 
@@ -62,7 +63,8 @@ dbg_printf (char const *msg, ...)
 }
 
 /* Until someone better comes along */
-const char version_etc_copyright[] = "Copyright %s %d Assaf Gordon" ;
+const char version_etc_copyright[] = "Copyright %s %d Assaf Gordon and \
+Timothy Rice";
 
 /* if true, enable developer's debug messages */
 static bool debug = false;
@@ -125,7 +127,7 @@ static struct option const longopts[] =
 };
 
 
-void
+static void
 add_sort_extra_args (char* s)
 {
   if (sort_extra_args_used == sort_extra_args_allocated )
@@ -135,7 +137,7 @@ add_sort_extra_args (char* s)
   sort_extra_args[sort_extra_args_used++] = xstrdup (s);
 }
 
-void
+static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
@@ -442,7 +444,7 @@ decorate_file (const char *infile)
           if (debug)
             dbg_printf ("skipping header line");
 
-          if (fwrite (lb.buffer, 1, lb.length, header_out) != lb.length)
+          if ((idx_t)fwrite (lb.buffer, 1, lb.length, header_out) != lb.length)
             die (SORT_FAILURE, errno, _("fwrite (header line) failed"));
 
           --skip_header_lines;
@@ -463,7 +465,7 @@ decorate_file (const char *infile)
       if (debug)
         dbg_printf ("writing line: '%.*s'", (int)lb.length, lb.buffer);
 
-      if (fwrite (lb.buffer, 1, lb.length, stdout) != lb.length)
+      if ((idx_t)fwrite (lb.buffer, 1, lb.length, stdout) != lb.length)
         die (SORT_FAILURE, errno, _("decorate: fwrite failed"));
 
     }
@@ -540,7 +542,7 @@ undecorate_file (const char *infile, int num_fields)
 
 
 /* this code was copied from src/sort.c */
-struct keyfield*
+static struct keyfield*
 parse_sort_key_arg (const char* optarg, char const** endpos)
 {
   char const *s;
@@ -646,7 +648,7 @@ parse_builtin_conversion_spec (const char* optarg, const char *s,
     badfieldspec (optarg, N_("invalid built-in conversion option"));
 }
 
-void check_allowed_key_flags (const struct keyfield* key)
+static void check_allowed_key_flags (const struct keyfield* key)
 {
   /* key->reverse is the only ordering flag allowed */
   if (key->skipsblanks || key->skipeblanks
@@ -658,7 +660,7 @@ void check_allowed_key_flags (const struct keyfield* key)
                              "not be combined with a conversion function"));
 }
 
-void parse_key_arg (const char* optarg)
+static void parse_key_arg (const char* optarg)
 {
   char const *s;
   struct keyfield *key = parse_sort_key_arg (optarg, &s);
@@ -690,7 +692,7 @@ void parse_key_arg (const char* optarg)
     }
 }
 
-void
+static void
 insert_decorate_key (struct keyfield *key_arg)
 {
   struct keyfield **p;
@@ -706,7 +708,7 @@ insert_decorate_key (struct keyfield *key_arg)
 }
 
 
-int
+static int
 adjust_key_fields ()
 {
   struct keyfield *key = keylist;
@@ -753,7 +755,7 @@ adjust_key_fields ()
   return cnt;
 }
 
-char**
+static char**
 build_sort_process_args ()
 {
   int argc = 3 ; /* one 'sort' program name (argv[0]), one extra arg on NetBSD,
@@ -797,7 +799,7 @@ build_sort_process_args ()
   return argv;
 }
 
-void
+static void
 free_sort_args (char **args)
 {
   for (char **arg = args; *arg; ++arg) {
@@ -852,7 +854,7 @@ main (int argc, char **argv)
 
   //atexit (close_stdout);
 
-  while ((opt = getopt_long (argc, argv, "cCHsS:T:uk:t:z",
+  while ((opt = getopt_long (argc, argv, "cCHsS:T:uk:t:zhV",
                              longopts, NULL)) != -1)
     {
       switch (opt)
