@@ -1,6 +1,7 @@
 /* GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -153,6 +154,8 @@ struct operation_data operations[] =
   {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_S_PEARSON_COR */
   {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
+  /* OP_DOT_PRODUCT */
+  {NUMERIC_VECTOR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_BIN_BUCKETS */
   {NUMERIC_SCALAR, IGNORE_FIRST, NUMERIC_RESULT},
   /* OP_STRBIN */
@@ -237,7 +240,7 @@ field_op_to_hex ( struct fieldop* op, const char *buffer, const size_t inlen )
 }
 
 /* Add a string to the strings vector, allocating memory as needed */
-void
+static void
 field_op_add_string (struct fieldop *op, const char* str, size_t slen)
 {
   if (op->str_buf_used + slen+1 >= op->str_buf_alloc)
@@ -254,7 +257,7 @@ field_op_add_string (struct fieldop *op, const char* str, size_t slen)
 
 /* Replace the current string in the string buffer.
    This function assumes only one string is stored in the buffer. */
-void
+static void
 field_op_replace_string (struct fieldop *op, const char* str, size_t slen)
 {
   if (slen+1 >= op->str_buf_alloc)
@@ -362,9 +365,7 @@ field_op_collect (struct fieldop *op,
 {
   char *endptr=NULL;
   long double num_value = 0;
-#ifdef HAVE_BROKEN_STRTOLD
   char tmpbuf[512];
-#endif
   enum FIELD_OP_COLLECT_RESULT rc = FLOCR_OK;
 
   assert (str != NULL); /* LCOV_EXCL_LINE */
@@ -374,25 +375,36 @@ field_op_collect (struct fieldop *op,
 
   if (op->numeric)
     {
-      errno = 0;
-#ifdef HAVE_BROKEN_STRTOLD
-      /* On Cygwin, strtold doesn't stop at a tab character,
-         and returns invalid value.
-         Make a copy of the input buffer and NULL-terminate it */
-      if (slen >= sizeof (tmpbuf))
-        die (EXIT_FAILURE, 0,
-                "internal error: input field too long (%zu)", slen);
-      memcpy (tmpbuf,str,slen);
-      tmpbuf[slen]=0;
-      num_value = strtold (tmpbuf, &endptr);
-      if (errno==ERANGE || endptr==tmpbuf || endptr!=(tmpbuf+slen))
-        return FLOCR_INVALID_NUMBER;
-#else
       if (slen == 0)
         return FLOCR_INVALID_NUMBER;
+#ifndef HAVE_BROKEN_STRTOLD
+      /* Usually, strtold stops at the field delimiter, but not always.
+         Optimistically try to avoid an extra copy, unless the strtold
+         implementation is known to be problematic. */
+      errno = 0;
       num_value = strtold (str, &endptr);
-      if (errno==ERANGE || endptr==str || endptr!=(str+slen))
+      if (errno==ERANGE || endptr==str || endptr<(str+slen))
         return FLOCR_INVALID_NUMBER;
+      /* On Cygwin, strtold doesn't stop at a tab character,
+         and returns invalid value.
+         Generally, strtold doesn't stop on field separators
+         that can be part of long double representations.
+         If strtold continued past the field delimiter, make
+         a copy of the input buffer and NUL-terminate it. */
+      if (endptr > (str+slen))
+        {
+#endif
+          if (slen >= sizeof (tmpbuf))
+            die (EXIT_FAILURE, 0,
+                    "internal error: input field too long (%zu)", slen);
+          memcpy (tmpbuf,str,slen);
+          tmpbuf[slen]=0;
+          errno = 0;
+          num_value = strtold (tmpbuf, &endptr);
+          if (errno==ERANGE || endptr==tmpbuf || endptr!=(tmpbuf+slen))
+            return FLOCR_INVALID_NUMBER;
+#ifndef HAVE_BROKEN_STRTOLD
+        }
 #endif
     }
 
@@ -494,7 +506,7 @@ field_op_collect (struct fieldop *op,
          and report any errors back to the caller. */
       {
         /* safe to assume decoded base64 is never larger than encoded base64 */
-        size_t decoded_size = slen;
+        idx_t decoded_size = slen;
         field_op_reserve_out_buf (op, decoded_size);
         if (!base64_decode ( str, slen, op->out_buf, &decoded_size ))
           return FLOCR_INVALID_BASE64;
@@ -553,6 +565,7 @@ field_op_collect (struct fieldop *op,
     case OP_S_COVARIANCE:
     case OP_P_PEARSON_COR:
     case OP_S_PEARSON_COR:
+    case OP_DOT_PRODUCT:
     case OP_TRIMMED_MEAN:
       field_op_add_value (op, num_value);
       break;
@@ -665,7 +678,7 @@ unique_value ( struct fieldop *op, bool case_sensitive )
 }
 
 /* Returns the number of unique string values in the given field operation */
-size_t
+static size_t
 count_unique_values ( struct fieldop *op, bool case_sensitive )
 {
   const char *last_str, **cur_str;
@@ -697,7 +710,7 @@ count_unique_values ( struct fieldop *op, bool case_sensitive )
 
 /* Returns a nul-terimated string, composed of all the values
    of the input strings. The return string must be free'd. */
-void
+static void
 collapse_value ( struct fieldop *op )
 {
   /* Copy the string buffer as-is */
@@ -750,6 +763,7 @@ field_op_summarize_empty (struct fieldop *op)
     case OP_S_COVARIANCE:
     case OP_P_PEARSON_COR:
     case OP_S_PEARSON_COR:
+    case OP_DOT_PRODUCT:
     case OP_BIN_BUCKETS:
     case OP_STRBIN:
     case OP_FLOOR:
@@ -997,6 +1011,14 @@ field_op_summarize (struct fieldop *op)
                                                 DF_POPULATION:DF_SAMPLE);
       break;
 
+    case OP_DOT_PRODUCT:
+      assert (!op->slave);                       /* LCOV_EXCL_LINE */
+      assert (op->slave_op);                     /* LCOV_EXCL_LINE */
+      verify_slave_num_values (op);
+      numeric_result = dot_product_value (op->values, op->slave_op->values,
+                                          op->num_values );
+      break;
+
     case OP_MODE:
     case OP_ANTIMODE:
       field_op_sort_values (op);
@@ -1165,31 +1187,6 @@ field_op_free (struct fieldop* op)
   op->field_name = NULL;
 }
 
-/* long mix function, from:
-   Robert Jenkins' 96 bit Mix Function
-   http://burtleburtle.net/bob/hash/doobs.html */
-static unsigned long
-mix (unsigned long a, unsigned long b, unsigned long c)
-{
-    a=a-b;  a=a-c;  a=a^(c >> 13);
-    b=b-c;  b=b-a;  b=b^(a << 8);
-    c=c-a;  c=c-b;  c=c^(b >> 13);
-    a=a-b;  a=a-c;  a=a^(c >> 12);
-    b=b-c;  b=b-a;  b=b^(a << 16);
-    c=c-a;  c=c-b;  c=c^(b >> 5);
-    a=a-b;  a=a-c;  a=a^(c >> 3);
-    b=b-c;  b=b-a;  b=b^(a << 10);
-    c=c-a;  c=c-b;  c=c^(b >> 15);
-    return c;
-}
-
-void
-init_random (void)
-{
-  unsigned long seed = mix (clock (), time (NULL), getpid ());
-  srandom (seed);
-}
-
 const char*
 field_op_collect_result_name (const enum FIELD_OP_COLLECT_RESULT flocr)
 {
