@@ -1,6 +1,7 @@
 /* GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -31,6 +32,7 @@
 #include "op-parser.h"
 #include "utils.h"
 #include "field-ops.h"
+#include "text-options.h"
 
 static struct datamash_ops *dm = NULL;
 
@@ -112,7 +114,8 @@ alloc_next_field ()
 #define OP_NEED_PAIR_PARAMS(x) (((x)==OP_P_COVARIANCE)||\
                                 ((x)==OP_S_COVARIANCE)||\
                                 ((x)==OP_P_PEARSON_COR)||\
-                                ((x)==OP_S_PEARSON_COR))
+                                ((x)==OP_S_PEARSON_COR)||\
+                                ((x)==OP_DOT_PRODUCT))
 
 #define ADD_NAMED_GROUP(name)  (add_group_col (true,0,(name)))
 #define ADD_NUMERIC_GROUP(num) (add_group_col (false,num,NULL))
@@ -261,6 +264,10 @@ parse_simple_operation_column (struct parser_field_t /*OUTPUT*/ *p,
 {
   assert (p);                                    /* LCOV_EXCL_LINE */
   enum TOKEN tok = scanner_get_token ();
+
+  if (vnlog && tok == TOK_INTEGER)
+    tok = TOK_IDENTIFIER;
+
   switch (tok)                                   /* LCOV_EXCL_BR */
     {
     case TOK_IDENTIFIER:
@@ -540,6 +547,10 @@ static void
 parse_mode_column (enum processing_mode pm)
 {
   enum TOKEN tok = scanner_get_token ();
+
+  if (vnlog && tok == TOK_INTEGER)
+    tok = TOK_IDENTIFIER;
+
   switch (tok)                                   /* LCOV_EXCL_BR */
     {
     case TOK_IDENTIFIER:
@@ -557,7 +568,27 @@ parse_mode_column (enum processing_mode pm)
     case TOK_INTEGER:
       if (scan_val_int>0)
         {
-          ADD_NUMERIC_GROUP (scan_val_int);
+          int begin_range = scan_val_int, end_range;
+          if (scanner_peek_token () != TOK_DASH)
+            {
+              ADD_NUMERIC_GROUP (scan_val_int);
+            }
+          else
+            {
+              scanner_get_token ();
+              if (scanner_get_token () != TOK_INTEGER
+                  || scan_val_int < (uintmax_t) begin_range)
+                {
+                  die (EXIT_FAILURE, 0,
+                       _("invalid field range for operation %s"),
+                       quote (get_processing_mode_name (pm)));
+                }
+              end_range = scan_val_int;
+              for (int i = begin_range; i <= end_range; i++)
+                {
+                  ADD_NUMERIC_GROUP (i);
+                }
+            }
           break;
         }
       /* fallthrough */
