@@ -8,6 +8,7 @@
 
    Modifications for GNU Datamash are
    Copyright (C) 2014-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,6 +28,7 @@
 
 #include <assert.h>
 #include <errno.h>
+#include <error.h>
 #include <getopt.h>
 #include <limits.h>
 #include <locale.h>
@@ -72,7 +74,6 @@ x2nrealloc (void *p, size_t *pn, size_t s)
 #  include "xalloc.h"
 #  include "c-ctype.h"
 #  include "quote.h"
-#  include "error.h"
 
 /* Take care of NLS matters.  */
 #include "gettext.h"
@@ -110,13 +111,10 @@ x2nrealloc (void *p, size_t *pn, size_t s)
 
 /* Factor out some of the common --help and --version processing code.  */
 
-/* These enum values cannot possibly conflict with the option values
-   ordinarily used by commands, including CHAR_MAX + 1, etc.  Avoid
-   CHAR_MIN - 1, as it may equal -1, the getopt end-of-options value.  */
 enum
 {
-  GETOPT_HELP_CHAR = (CHAR_MIN - 2),
-  GETOPT_VERSION_CHAR = (CHAR_MIN - 3)
+  GETOPT_HELP_CHAR = 'h',
+  GETOPT_VERSION_CHAR = 'V'
 };
 
 #define GETOPT_HELP_OPTION_DECL \
@@ -130,9 +128,9 @@ enum
     break;
 
 #define HELP_OPTION_DESCRIPTION \
-  _("      --help     display this help and exit\n")
+  _("  -h, --help     display this help and exit\n")
 #define VERSION_OPTION_DESCRIPTION \
-  _("      --version  output version information and exit\n")
+  _("  -V, --version  output version information and exit\n")
 
 static inline void
 emit_try_help (void)
