@@ -1,7 +1,7 @@
 /* GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
-   Copyright (C) 2022-     Tim Rice     <trice@posteo.net>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -117,6 +117,13 @@ long double
 pearson_corr_value ( const long double * const valuesA,
                      const long double * const valuesB, size_t n, int df);
 
+/*
+ Given two columns of doubles, return their scalar product value.
+ */
+long double
+dot_product_value ( const long double * const valuesA,
+                    const long double * const valuesB, size_t n );
+
 /*
  Given an array of doubles, return the standard-deviation value.
  'df' is degrees-of-freedom. Use DF_POPULATION or DF_SAMPLE (see above).
