@@ -3,6 +3,7 @@
   Unit Tests for GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -84,7 +85,7 @@ my @Tests =
   ['e25','sum 1--5',   {IN_PIPE=>""}, {EXIT=>1},
     {ERR=>"$prog: invalid field range for operation 'sum'\n"}],
 
-  # Test field pair syntaax
+  # Test field pair syntax
   ['e41','pcov 1', {IN_PIPE=>""}, {EXIT=>1},
     {ERR=>"$prog: operation 'pcov' requires field pairs\n"}],
   ['e42','pcov 1:', {IN_PIPE=>""}, {EXIT=>1},
@@ -97,6 +98,16 @@ my @Tests =
     {ERR=>"$prog: -H or --header-in must be used with named columns\n"}],
   ['e47','sum 1:3', {IN_PIPE=>""}, {EXIT=>1},
     {ERR=>"$prog: operation 'sum' cannot use pair of fields\n"}],
+  ['e50','dotprod 1', {IN_PIPE=>""}, {EXIT=>1},
+    {ERR=>"$prog: operation 'dotprod' requires field pairs\n"}],
+  ['e51','dotprod 1:', {IN_PIPE=>""}, {EXIT=>1},
+    {ERR=>"$prog: invalid field pair for operation 'dotprod'\n"}],
+  ['e52','dotprod :', {IN_PIPE=>""}, {EXIT=>1},
+    {ERR=>"$prog: invalid field pair for operation 'dotprod'\n"}],
+  ['e53','dotprod :1', {IN_PIPE=>""}, {EXIT=>1},
+    {ERR=>"$prog: invalid field pair for operation 'dotprod'\n"}],
+  ['e54','dotprod hello:world', {IN_PIPE=>""}, {EXIT=>1},
+    {ERR=>"$prog: -H or --header-in must be used with named columns\n"}],
 
   # Test scanner edge-cases
   # Floating point value
@@ -175,8 +186,6 @@ my @Tests =
   # Invalid field specifications for primary operations
   ['e90',  'groupby 1:2', {IN_PIPE=>""}, {EXIT=>1},
     {ERR=>"$prog: invalid field pair for operation 'groupby'\n"}],
-  ['e91',  'groupby 1-2', {IN_PIPE=>""}, {EXIT=>1},
-    {ERR=>"$prog: invalid field range for operation 'groupby'\n"}],
 
   # values for strbin operation
   ['e92','strbin:-  1',    {IN_PIPE=>""}, {EXIT=>1},
@@ -267,6 +276,16 @@ my @Tests =
   ['e152', 'sum 2', {IN_PIPE=>"1.2\t3.4.5\n"}, {EXIT=>1},
     {ERR=>"$prog: invalid numeric value in line 1 field 2: '3.4.5'\n"}],
 
+  # bad seeds
+  ['e153', '-S1.1 rand 1',
+    {IN_PIPE=>"1\n"}, {EXIT=>1},
+    {ERR=>"$prog: invalid seed\n"}],
+  ['e154', '-S-1 rand 1',
+    {IN_PIPE=>"1\n"}, {EXIT=>1},
+    {ERR=>"$prog: invalid seed\n"}],
+  ['e155', '-Sa rand 1',
+    {IN_PIPE=>"1\n"}, {EXIT=>1},
+    {ERR=>"$prog: invalid seed\n"}],
 );
 
 my $save_temps = $ENV{SAVE_TEMPS};
