@@ -1,7 +1,7 @@
 #!/bin/sh
 #   Unit Tests for GNU Datamash - perform simple calculation on input data
 
-#    Copyright (C) 2014-2020 Assaf Gordon <assafgordon@gmail.com>
+#    Copyright (C) 2014-2021 Assaf Gordon <assafgordon@gmail.com>
 #
 #    This file is part of GNU Datamash.
 #
@@ -31,7 +31,7 @@ fail=0
 require_paste_
 
 ## Ensure seq is useable
-## (not installed on OpenBSD by default)
+openbsd_seq_replacement_
 seq 10 >/dev/null 2>/dev/null ||
     skip_ "requires a working seq"
 
