@@ -3,6 +3,7 @@
   Unit Tests for GNU Datamash - perform simple calculation on input data
 
    Copyright (C) 2013-2021 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2022-2025 Timothy Rice <trice@posteo.net>
 
    This file is part of GNU Datamash.
 
@@ -301,6 +302,20 @@ bar	5
 ;baz	7
 EOF
 
+my $in_comments2=<<'EOF';
+ #foo	3
+bar	5
+;baz	7
+frob	9;
+EOF
+
+my $in_comments3=<<'EOF';
+ #foo	3
+bar	5
+;baz	7
+frob	9#
+EOF
+
 my $in_esc_ident=<<'EOF';
 A_Chlor_T1h_r1-metaG B 9C -bar
 1 2 3 4
@@ -575,13 +590,19 @@ my @Tests =
           "5	bar\n" .
           "7	;baz\n"}],
   ['sc4', '-C reverse', {IN_PIPE=>$in_comments}, {OUT=>"5	bar\n"}],
+  # datamash supports only comment lines, but not inline comments
+  ['sce1', '-C sum 2',  {IN_PIPE=>$in_comments2}, {EXIT=>1},
+    {ERR=>"$prog: invalid numeric value in line 2 field 2: '9;'\n"}],
+  ['sce2', '-C sum 2',  {IN_PIPE=>$in_comments3}, {EXIT=>1},
+    {ERR=>"$prog: invalid numeric value in line 2 field 2: '9#'\n"}],
 
 
   # Regression tests
   # TODO: Move regression tests into a separate file when sufficiently many
   #       have accumulated to warrant the overhead of another test file.
   # Bug in mode/antimode in 1.4 and earlier
-  ['bug_mode1', 'mode 1', {IN_PIPE=>"-1"}, {OUT=>"-1\n"}],
+  ['bug_mode1',     'mode 1',     {IN_PIPE=>"-1"}, {OUT=>"-1\n"}],
+  ['bug_antimode1', 'antimode 1', {IN_PIPE=>"-1"}, {OUT=>"-1\n"}],
   # "Segmentation fault" when input contains embedded NUL characters
   # (see https://lists.gnu.org/archive/html/bug-datamash/2020-11/msg00001.html)
   ['regr001', 'countunique 1', {IN_PIPE=>"\x00" x 100}, {OUT=>"1\n"}],
@@ -641,6 +662,12 @@ my @Tests =
     {OUT=>"0\n"}],
   ['gn16', 'getnum:n 1', {IN_PIPE=>"moo" x 4000 . "42" . "bar" x 1000},
     {OUT=>"42\n"}],
+  ['gn17', 'getnum 1',      {IN_PIPE=>"abc\t123\n"}, {OUT=>"0\n"}],
+  ['gn18', 'getnum 2',      {IN_PIPE=>"abc\t123\n"}, {OUT=>"123\n"}],
+  ['gn19', '-t, getnum 1',  {IN_PIPE=>"abc,123\n"},  {OUT=>"0\n"}],
+  ['gn20', '-t, getnum 2',  {IN_PIPE=>"abc,123\n"},  {OUT=>"123\n"}],
+  ['gn21', '-t: getnum 1',  {IN_PIPE=>"abc:123\n"},  {OUT=>"0\n"}],
+  ['gn22', '-t: getnum 2',  {IN_PIPE=>"abc:123\n"},  {OUT=>"123\n"}],
 
 
   # cut operation
@@ -670,11 +697,56 @@ my @Tests =
   ['ifdl09', '-t. rmdup 1',           {IN_PIPE=>"1.2\n"},   {OUT=>"1.2\n"}],
   ['ifdl10', '-t. rmdup 2',           {IN_PIPE=>"1.2\n"},   {OUT=>"1.2\n"}],
   ['ifdl11', '-t. rmdup 3',           {IN_PIPE=>"1.2.3\n"}, {OUT=>"1.2.3\n"}],
-  # TODO: fix bug for numeric operations
-  #['ifdl12', '-t. sum 1,2',           {IN_PIPE=>"1.2\n"},   {OUT=>"1.2\n"}],
-  #['ifdl13', '-t. sum 1,2,3',         {IN_PIPE=>"1.2.3\n"}, {OUT=>"1.2.3\n"}],
-  # TODO: fix bug for "getnum" operation
-  #['ifdl14', '-t. getnum 1,2',        {IN_PIPE=>"x1.2y\n"}, {OUT=>"1.2\n"}],
+  ['ifdl12', '-t. sum 1,2',           {IN_PIPE=>"1.2\n"},   {OUT=>"1.2\n"}],
+  ['ifdl13', '-t. sum 1,2,3',         {IN_PIPE=>"1.2.3\n"}, {OUT=>"1.2.3\n"}],
+  ['ifdl14', '-t. getnum 1,2',        {IN_PIPE=>"x1.2y\n"}, {OUT=>"1.2\n"}],
+  ['ifdl15', '-t. getnum 1',          {IN_PIPE=>"x2.3y\n"}, {OUT=>"2\n"}],
+  ['ifdl16', '-t. getnum 2',          {IN_PIPE=>"x2.3y\n"}, {OUT=>"3\n"}],
+
+  # Test mode operation
+  ['mode01', 'mode 1', {IN_PIPE=>"1\n1\n2\n"},                    {OUT=>"1\n"}],
+  ['mode02', 'mode 1', {IN_PIPE=>"1\n2\n2\n"},                    {OUT=>"2\n"}],
+  ['mode03', 'mode 1', {IN_PIPE=>"1\n2\n2\n3\n3\n3\n"},           {OUT=>"3\n"}],
+  ['mode04', 'mode 1', {IN_PIPE=>"1\n1\n1\n2\n2\n3\n"},           {OUT=>"1\n"}],
+  ['mode05', 'mode 1', {IN_PIPE=>"1\n1\n2\n2\n2\n3\n"},           {OUT=>"2\n"}],
+  ['mode06', 'mode 1', {IN_PIPE=>"1\n2\n2\n3\n3\n3\n"},           {OUT=>"3\n"}],
+  ['mode07', 'mode 1', {IN_PIPE=>"1\n1\n1\n2\n3\n3\n"},           {OUT=>"1\n"}],
+  ['mode08', 'mode 1',{IN_PIPE=>"1\n2\n2\n3\n3\n3\n4\n4\n4\n4\n"},{OUT=>"4\n"}],
+  ['mode09', 'mode 1',{IN_PIPE=>"1\n2\n2\n3\n3\n3\n3\n4\n4\n4\n"},{OUT=>"3\n"}],
+  ['mode10', 'mode 1',{IN_PIPE=>"1\n2\n2\n2\n2\n3\n3\n4\n4\n4\n"},{OUT=>"2\n"}],
+  ['mode11', 'mode 1',{IN_PIPE=>"1\n1\n1\n1\n2\n2\n3\n3\n3\n4\n"},{OUT=>"1\n"}],
+  ['mode12', 'mode 1', {IN_PIPE=>"9\n"},                          {OUT=>"9\n"}],
+  ['mode13', 'mode 1',
+    {IN_PIPE=>"1\n1\n1\n2\n2\n2\n2\n3\n3\n4\n4\n4\n4\n4\n"},      {OUT=>"4\n"}],
+
+  # Test antimode operation
+  ['antimode01', 'antimode 1', {IN_PIPE=>"1\n1\n2\n"},          {OUT=>"2\n"}],
+  ['antimode02', 'antimode 1', {IN_PIPE=>"1\n2\n2\n"},          {OUT=>"1\n"}],
+  ['antimode03', 'antimode 1', {IN_PIPE=>"1\n2\n2\n3\n3\n3\n"}, {OUT=>"1\n"}],
+  ['antimode04', 'antimode 1', {IN_PIPE=>"1\n1\n2\n3\n3\n3\n"}, {OUT=>"2\n"}],
+  ['antimode05', 'antimode 1', {IN_PIPE=>"1\n1\n1\n2\n2\n3\n"}, {OUT=>"3\n"}],
+  ['antimode06', 'antimode 1', {IN_PIPE=>"1\n1\n2\n2\n2\n3\n"}, {OUT=>"3\n"}],
+  ['antimode07', 'antimode 1', {IN_PIPE=>"1\n2\n2\n3\n3\n3\n"}, {OUT=>"1\n"}],
+  ['antimode08', 'antimode 1', {IN_PIPE=>"1\n1\n1\n2\n3\n3\n"}, {OUT=>"2\n"}],
+  ['antimode09', 'antimode 1',
+    {IN_PIPE=>"1\n2\n2\n3\n3\n3\n4\n4\n4\n4\n"}, {OUT=>"1\n"}],
+  ['antimode10', 'antimode 1',
+    {IN_PIPE=>"1\n2\n2\n3\n3\n3\n3\n4\n4\n4\n"}, {OUT=>"1\n"}],
+  ['antimode11', 'antimode 1',
+    {IN_PIPE=>"1\n2\n2\n2\n2\n3\n3\n4\n4\n4\n"}, {OUT=>"1\n"}],
+  ['antimode12', 'antimode 1',
+    {IN_PIPE=>"1\n1\n1\n1\n2\n2\n3\n3\n3\n4\n"}, {OUT=>"4\n"}],
+  ['antimode13', 'antimode 1',
+    {IN_PIPE=>"1\n1\n1\n1\n2\n3\n3\n3\n4\n4\n"}, {OUT=>"2\n"}],
+  ['antimode14', 'antimode 1',
+    {IN_PIPE=>"1\n1\n1\n1\n2\n2\n3\n4\n4\n4\n"}, {OUT=>"3\n"}],
+  ['antimode15', 'antimode 1',
+    {IN_PIPE=>"1\n1\n2\n2\n2\n3\n4\n4\n4\n4\n"}, {OUT=>"3\n"}],
+  ['antimode16', 'antimode 1',
+    {IN_PIPE=>"1\n1\n2\n2\n3\n3\n4\n"},          {OUT=>"4\n"}],
+  ['antimode17', 'antimode 1', {IN_PIPE=>"9\n"}, {OUT=>"9\n"}],
+  ['antimode18', 'antimode 1',
+    {IN_PIPE=>"1\n1\n1\n2\n2\n2\n2\n3\n3\n4\n4\n4\n4\n4\n"}, {OUT=>"3\n"}],
 
 );
 
